@@ -12,6 +12,7 @@ def add_root_dirs():
     package_dir = os.path.join(
         root_dir, "{% raw %}{{cookiecutter.package_name}}{% endraw %}"
     )
+    hooks_dir = os.path.join(template_dir, "hooks")
 
     try:
         os.mkdir(root_dir)
@@ -23,6 +24,11 @@ def add_root_dirs():
     except OSError:
         pass
 
+    try:
+        os.mkdir(hooks_dir)
+    except OSError:
+        pass
+
 
 if __name__ == "__main__":
     add_root_dirs()
